import pandas as pd
from fbprophet import Prophet
from matplotlib import pyplot as plt
import os
def all_cases(country,path_csv,dir_name,out_csv): 
	df = pd.read_csv(path_csv,parse_dates=['Last Update'])
	country_data = df[df['Country/Region']==country]
	#idata = country_data.tail(22)
	#idata.head()
	country_all_cases = country_data.groupby(["ObservationDate"])[['Confirmed', 'Deaths', 'Recovered']].sum().reset_index()
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_cases=pd.DataFrame(country_all_cases ,columns=['ObservationDate','Confirmed','Deaths','Recovered'])
	country_cases.to_csv(dir_name+'/'+'all_cases_'+out_csv)
	plt.figure(figsize=(23,10))
	plt.bar(country_cases.ObservationDate, country_cases.Confirmed,label="Confirmed Case")
	plt.bar(country_cases.ObservationDate, country_cases.Deaths,label="Deaths Case")
	plt.bar(country_cases.ObservationDate, country_cases.Recovered,label="Recovered Case")

	plt.xlabel('Date')
	plt.ylabel("Count")
	plt.legend(frameon=True, fontsize=12)
	plt.title('All Cases',fontsize = 35)
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_all_cases'+'.png')
	return(country_cases)
def confirmed_case(country,path_csv,dir_name,out_csv): 
	df = pd.read_csv(path_csv,parse_dates=['Last Update'])
	country_data = df[df['Country/Region']==country]
	#idata = country_data.tail(22)
	#idata.head()
	country_confirmed = country_data.groupby(["ObservationDate"])[['Confirmed']].sum().reset_index()
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_confirmed_case=pd.DataFrame(country_confirmed ,columns=['ObservationDate','Confirmed'])
	country_confirmed_case.to_csv(dir_name+'/'+'confirmed_'+out_csv)
	plt.figure(figsize=(23,10))
	plt.bar(country_confirmed.ObservationDate, country_confirmed.Confirmed,label="Confirmed Case")
	plt.xlabel('Date')
	plt.ylabel("Count")
	plt.legend(frameon=True, fontsize=12)
	plt.title('Confirmed Case',fontsize = 35)
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_confirmed'+'.png')
	return(country_confirmed_case)
def deaths_case(country,path_csv,dir_name,out_csv): 
	df = pd.read_csv(path_csv,parse_dates=['Last Update'])
	country_data = df[df['Country/Region']==country]
	#idata = country_data.tail(22)
	#idata.head()
	country_death = country_data.groupby(["ObservationDate"])[['Deaths']].sum().reset_index()
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_death_case=pd.DataFrame(country_death ,columns=['ObservationDate','Deaths'])
	country_death_case.to_csv(dir_name+'/'+'death_'+out_csv)
	plt.figure(figsize=(23,10))
	plt.bar(country_death.ObservationDate, country_death.Deaths,label="Deaths Case")
	plt.xlabel('Date')
	plt.ylabel("Count")
	plt.legend(frameon=True, fontsize=12)
	plt.title('Deaths Case',fontsize = 35)
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_deaths'+'.png')
	return(country_death_case)
def recoverd_case(country,path_csv,dir_name,out_csv): 
	df = pd.read_csv(path_csv,parse_dates=['Last Update'])
	country_data = df[df['Country/Region']==country]
	#idata = country_data.tail(22)
	#idata.head()
	country_recoverd = country_data.groupby(["ObservationDate"])[['Recovered']].sum().reset_index()
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_recoverd_case=pd.DataFrame(country_recoverd ,columns=['ObservationDate','Recovered'])
	country_recoverd_case.to_csv(dir_name+'/'+'recoverd_'+out_csv)
	plt.figure(figsize=(23,10))
	plt.bar(country_recoverd.ObservationDate, country_recoverd.Recovered,label="Recovered Cases")
	plt.xlabel('Date')
	plt.ylabel("Count")
	plt.legend(frameon=True, fontsize=12)
	plt.title('Recovered Case',fontsize = 35)
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_recoverd'+'.png')
	return(country_recoverd_case)


import pandas as pd
from fbprophet import Prophet
from matplotlib import pyplot as plt
import os
def confirmed_forecast(country_confirmed,next_periods,dir_name,csv_name,country):
	ObservationDate_x_ticks = []
	ObservationDate_confirmed=[]
	for index, row in country_confirmed.iterrows():
		ObservationDate_x_ticks.append(row['ObservationDate'])
		ObservationDate_confirmed.append(row['Confirmed'])
		ObservationDate_confirmed_prophet =country_confirmed[['ObservationDate', 'Confirmed']]
		ObservationDate_confirmed_prophet.columns = ['ds', 'y']
	model_confirmed = Prophet(interval_width=0.99)
	model_confirmed.fit(ObservationDate_confirmed_prophet)
	future_confirmed = model_confirmed.make_future_dataframe(periods=next_periods)
	forecast_confirmed = model_confirmed.predict(future_confirmed)
	model_confirmed.plot(forecast_confirmed)
	model_confirmed.plot_components(forecast_confirmed)
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	forecast_confirmed_yhat = []
	forecast_confirmed_yhat_u = []
	forecast_confirmed_yhat_l = []
	for index, row in forecast_confirmed.iterrows():
		 forecast_confirmed_yhat.append(row['yhat'])
		 forecast_confirmed_yhat_l.append(row['yhat_lower'])
		 forecast_confirmed_yhat_u.append(row['yhat_upper'])
	plt.figure(figsize=(23,10))
	plt.xlabel('Days')
	plt.ylabel('Confirmed Case')
	plt.plot(forecast_confirmed_yhat, label='Prediction', color='blue')
	plt.plot(forecast_confirmed_yhat_l, label='Prediction lower', color='red')
	plt.plot(forecast_confirmed_yhat_u, label='Predicition upper', color='green')
	plt.title("Forecast of Confirmed Case ")
	plt.legend()
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_forecast_confirmed'+'.png')
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_forecasting_confirmed=pd.DataFrame(forecast_confirmed,columns=['ds','yhat','yhat_lower','yhat_upper'])
	country_forecasting_confirmed.to_csv(dir_name+'/forecast_confirmed_'+csv_name)
	return forecast_confirmed  
def deaths_forecast(country_death,next_periods,dir_name,csv_name,country):
	ObservationDate_x_ticks = []
	ObservationDate_country_death=[]
	for index, row in country_death.iterrows():
		ObservationDate_x_ticks.append(row['ObservationDate'])
		ObservationDate_country_death.append(row['Deaths'])
		ObservationDate_country_death_prophet =country_death[['ObservationDate', 'Deaths']]
		ObservationDate_country_death_prophet.columns = ['ds', 'y']
	model_country_death = Prophet(interval_width=0.99)
	model_country_death.fit(ObservationDate_country_death_prophet)
	future_country_death = model_country_death.make_future_dataframe(periods=next_periods)
	forecast_country_death = model_country_death.predict(future_country_death)
	model_country_death.plot(forecast_country_death)
	model_country_death.plot_components(forecast_country_death)
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	forecast_country_death_yhat = []
	forecast_country_death_yhat_u = []
	forecast_country_death_yhat_l = []
	for index, row in forecast_country_death.iterrows():
		 forecast_country_death_yhat.append(row['yhat'])
		 forecast_country_death_yhat_l.append(row['yhat_lower'])
		 forecast_country_death_yhat_u.append(row['yhat_upper'])
	plt.figure(figsize=(23,10))
	plt.xlabel('Days')
	plt.ylabel('Deaths Case')
	plt.plot(forecast_country_death_yhat, label='Prediction', color='blue')
	plt.plot(forecast_country_death_yhat_l, label='Prediction lower', color='red')
	plt.plot(forecast_country_death_yhat_u, label='Predicition upper', color='green')
	plt.title("Forecast of Deaths Case ")
	plt.legend()
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_forecast_deaths'+'.png')
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_forecasting_country_death=pd.DataFrame(forecast_country_death,columns=['ds','yhat','yhat_lower','yhat_upper'])
	country_forecasting_country_death.to_csv(dir_name+'/forecast_deaths_'+csv_name)
	return forecast_country_death  
def recoverd_forecast(country_recoverd,next_periods,dir_name,csv_name,country):
	ObservationDate_x_ticks = []
	ObservationDate_country_recoverd=[]
	for index, row in country_recoverd.iterrows():
		ObservationDate_x_ticks.append(row['ObservationDate'])
		ObservationDate_country_recoverd.append(row['Recovered'])
		ObservationDate_country_recoverd_prophet =country_recoverd[['ObservationDate', 'Recovered']]
		ObservationDate_country_recoverd_prophet.columns = ['ds', 'y']
	model_country_recoverd = Prophet(interval_width=0.99)
	model_country_recoverd.fit(ObservationDate_country_recoverd_prophet)
	future_country_recoverd = model_country_recoverd.make_future_dataframe(periods=next_periods)
	forecast_country_recoverd = model_country_recoverd.predict(future_country_recoverd)
	model_country_recoverd.plot(forecast_country_recoverd)
	model_country_recoverd.plot_components(forecast_country_recoverd)
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	forecast_country_recoverd_yhat = []
	forecast_country_recoverd_yhat_u = []
	forecast_country_recoverd_yhat_l = []
	for index, row in forecast_country_recoverd.iterrows():
		 forecast_country_recoverd_yhat.append(row['yhat'])
		 forecast_country_recoverd_yhat_l.append(row['yhat_lower'])
		 forecast_country_recoverd_yhat_u.append(row['yhat_upper'])
	plt.figure(figsize=(23,10))
	plt.xlabel('Days')
	plt.ylabel('Recovered Case')
	plt.plot(forecast_country_recoverd_yhat, label='Prediction', color='blue')
	plt.plot(forecast_country_recoverd_yhat_l, label='Prediction lower', color='red')
	plt.plot(forecast_country_recoverd_yhat_u, label='Predicition upper', color='green')
	plt.title("Forecast of Recovered Case ")
	plt.legend()
	#plt.show()
	plt.savefig(dir_name+'/'+country+'_forecast_recoverd'+'.png')
	if not os.path.exists(dir_name):
		os.mkdir(dir_name)
		print("Directory " , dir_name ,  " Created ")
	else:    
		print("Directory " , dir_name ,  " already exists")
	country_forecasting_country_recoverd=pd.DataFrame(forecast_country_recoverd,columns=['ds','yhat','yhat_lower','yhat_upper'])
	country_forecasting_country_recoverd.to_csv(dir_name+'/forecast_recoverd_'+csv_name)
	return forecast_country_recoverd  



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="covid19forecast", # Replace with your own username
    version="1.1.0",
    author="Falah.G.Saleh",
    author_email="falahgs07@gmail.com",
    description="Python Package to get Covid19  Forecasting For all Cases Every Country in future using FBProphet Model",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://iraqprogrammer.wordpress.com/",
    packages=["covid19forecast"],
	keywords = ['Covid19', 'CoronaVirus', 'Forecasting'],
	install_requires=[            # I get to this in a second
          'fbprophet',
          'pandas',
		  'matplotlib',
      ],
    classifiers=[
        "Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.5",
		"Programming Language :: Python :: 3.6",
		"Programming Language :: Python :: 3.7",
		"Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)